package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````@"$```````!``````````(@!`0``
M`````````$``.``)`$``&@`9``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````-B<````````V)P`````````
M``$```````$````&````>/L```````!X^P$``````'C[`0``````"`4`````
M```P!0```````````0```````@````8```"(^P```````(C[`0``````B/L!
M```````0`@```````!`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````D)4```````"0E0```````)"5````````_`````````#\``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````'C[````````>/L!``````!X^P$`
M`````(@$````````B`0````````!`````````"]L:6(O;&0M;&EN=7@M86%R
M8V@V-"YS;RXQ```$````%`````,```!'3E4`B&T>_'687?P`DFWBU;A]A!@0
M_=@$````$`````$```!'3E4```````,````'`````````!$```!+````!```
M``@````A$!``!<`$A"@"$`6`AD"$@@D`!`D@!(B(@!!!N@`""$L```!,````
M3P```%,```!4````7````%T```!>`````````&````!A````8@```&,```!D
M````9P```````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[;49-1\=E0\E"'_
MY`[9<5@<XD?&`;(!BV^L2^/`0OK7A\+E/RQ8[Y=YNN.2?/NA;&!K"4/69Z_,
M9D)%U>R)!W#3,V+;[16,)<P-.I<+?ZF<F^"G`@IJ&IY0O]I7&Z/@^TD`````
M`````````````````````````````````P`+`"`;````````````````````
M`````P`6`````@````````````````#<````$@``````````````````````
M``#J`0``$@````````````````````````"#````$@``````````````````
M``````#1````$0````````````````````````!5`0``$@``````````````
M``````````"+`@``$@````````````````````````#Q`0``$@``````````
M``````````````#R````$@`````````````````````````=````(```````
M``````````````````"I`@``$@````````````````````````"9`0``$@``
M``````````````````````"N`P``$@`````````````````````````C`0``
M$@````````````````````````#L`@``$0`````````````````````````3
M`0``$@````````````````````````!L`@``$@``````````````````````
M```%`0``$@`````````````````````````_`@``$@``````````````````
M``````"D`@``$@````````````````````````!S`@``$@``````````````
M``````````!'`@``$@````````````````````````!^`0``(@``````````
M```````````````!````(``````````````````````````>`@``$@``````
M``````````````````!S`0``$@`````````````````````````L````(```
M```````````````````````5`@``$@````````````````````````#_`0``
M$@````````````````````````!\`@``$@````````````````````````##
M`@``$@````````````````````````!E`@``$0``````````````````````
M``!1`@``$@````````````````````````!&````$@``````````````````
M``````!%`0``$@````````````````````````!C````$@``````````````
M```````````E`@``$@````````````````````````#`````$@``````````
M``````````````!T````$@`````````````````````````'`@``$@``````
M``````````````````"3`@``$@````````````````````````#:`@``$@``
M``````````````````````"-`0``$@````````````````````````#.`0``
M$@````````````````````````"D````$@````````````````````````"R
M`@``$@`````````````````````````W`0``$@``````````````````````
M``!L`0``$@````````````````````````#F````$@``````````````````
M``````![`@``$@````````````````````````#<`0``$@``````````````
M``````````"H`0``$@````````````````````````"#`@``$@``````````
M```````````````X`@``$@````````````````````````"/````$@``````
M``````````````````"2`0``$@````````````````````````!@`0``$@``
M``````````````````````#*`@``$@`````````````````````````.`@``
M$@````````````````````````"S````$0````````````````````````#A
M````$@`````````````````````````L`0``$@``````````````````````
M``!4````$@````````````````````````"@`0``$@``````````````````
M```````K`@``$@````````````````````````"\`0``$@``````````````
M``````````#0`@``$0````````````````````````#C`0``$@``````````
M``````````````#1`@``(0`````````````````````````Q`@``$@``````
M``````````````````!7`@``$@````````````````````````#2`@``$0``
M``````````````````````#X`0``$@`````````````````````````)!```
M$``7`*@``@````````````````"W`P``$@`-`(`^````````,`$````````N
M!```$@`-`.`T````````.`<```````#)`0``$@`-`$`?````````'`(`````
M```N`P``$@`-`&0J````````!`````````!,`P``$@`-`"`\````````7`(`
M``````#?`P``$``7`(```@````````````````!4!```$@`-`'`J````````
M+`(````````4!```$``7`(```@`````````````````_`P``$@`-`*`L````
M````+`````````!B`P``$@`-``0S````````D`````````##`P``$0`/`*!3
M````````!`````````#M`P``$@`-`+!0````````"`$```````#X`P``$@`-
M`$`I````````.```````````!```$``7`*@``@`````````````````I!```
M$``7`*@``@````````````````!"!```$@`-`+0S````````+`$```````#2
M`P``$``6`````@````````````````"&`P``$@`-`-`L````````:`$`````
M```[!```$``6`(```@````````````````!A!```$0`6`'@``@``````"```
M``````#8`P``$@`-`(`A````````-``````````@!```$@`-`'!0````````
M0`````````#4`P``(``6`````@````````````````"<`P``$@`-`)0S````
M````(`````````!P`P``$@`-`(`I````````Y`````````"2`P``$@`-`,!1
M````````P`$````````(!```$``7`*@``@````````````````!K!```$@`-
M`$`N````````Q`0`````````7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE
M`%]?9VUO;E]S=&%R=%]?`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R
M;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E
M<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT
M`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S
M`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K
M7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U
M;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E
M<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`7U]C>&%?
M9FEN86QI>F4`<F5A9`!S=')C:'(`9V5T<&ED`&UE;6UO=F4`<'1H<F5A9%]G
M971S<&5C:69I8P!?7VQI8F-?<W1A<G1?;6%I;@!?7V9P<FEN=&9?8VAK`'-T
M<F-M<`!O<&5N-C0`=6YL:6YK`'-T<G1O:P!M96US970`<W1R;F-M<`!G971U
M:60`;65M8VAR`&-L;W-E9&ER`'-T<G-T<@!R;61I<@!C;&]S90!S=')L96X`
M<W1R9'5P`')E86QL;V,`<F5A9&1I<C8T`&%B;W)T`%]?<W!R:6YT9E]C:&L`
M<W1D97)R`&UE;6-P>0!S=')R8VAR`&QS=&%T-C0`;W!E;F1I<@!L<V5E:S8T
M`%]?97)R;F]?;&]C871I;VX`97AI=`!R96%D;&EN:P!?7W-T86-K7V-H:U]F
M86EL`&%C8V5S<P!M:V1I<@!?7V5N=FER;VX`7U]R96=I<W1E<E]A=&9O<FL`
M7U]S=&%C:U]C:&M?9W5A<F0`;&EB<&5R;"YS;RXU+C,T`&QI8F,N<V\N-@!L
M9"UL:6YU>"UA87)C:#8T+G-O+C$`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S
M96YA;64`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R
M7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G971?
M=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?
M=7-E9`!?7V1A=&%?<W1A<G0`7U]B<W-?<W1A<G1?7P!S:&%?=7!D871E`'AS
M7VEN:70`7U]E;F1?7P!?7V)S<U]E;F1?7P!?7V)S<U]S=&%R=`!S:&%?:6YI
M=`!?96YD`'!A<E]M:W1M<&1I<@!?961A=&$`<&%R7W-E='5P7VQI8G!A=&@`
M<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?:6YI=%]E;G8`1TQ)0D-?,BXQ
M-P!'3$E"0U\R+C,T`$=,24)#7S(N,S,```````````$``@`!``$``0`"``(`
M`0`!``(``@`"``$``P`!``(``0`"``(``@`"``(``0`"``$``0`"``(`!``"
M``(``@`!``$``0`"``$``0`"``(``@`"``(``0`"``$``@`!``0``@`%``(`
M`@`!``(``0`"``(``0`"``$``0`"``(`!0`"``(``@`"``(``@`"``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`````````!``$`&`,``!`````@````EY&6!@```P!X!```````
M``$``P`.`P``$`````````"TD98&```%`(,$```0````LY&6!@``!`".!```
M$````)>1E@8```(`>`0```````!X^P$```````,$````````D"(```````"`
M^P$```````,$````````0"(```````#X_P$```````,$````````0!\`````
M```(``(```````,$````````"``"```````8``(```````,$````````4%<`
M```````@``(```````,$````````$%0````````P``(```````,$````````
M`%4````````X``(```````,$````````,%<```````!```(```````,$````
M````.%<```````!(``(```````,$````````0%<```````!0``(```````,$
M````````2%<```````!@``(```````,$````````&%<```````!H``(`````
M``,$````````(%<```````!X``(```````,$````````6%<```````"8_P$`
M``````$$```&``````````````"@_P$```````$$```*``````````````"H
M_P$```````$$```+``````````````"P_P$```````$$```0````````````
M``"X_P$```````$$```8``````````````#`_P$```````$$```9````````
M``````#(_P$```````$$```<``````````````#0_P$```````$$```A````
M``````````#8_P$```````$$```D``````````````#@_P$```````$$```E
M``````````````#H_P$```````$$```]``````````````#P_P$```````$$
M``!)``````````````"P_0$```````($```#``````````````"X_0$`````
M``($```$``````````````#`_0$```````($```%``````````````#(_0$`
M``````($```'``````````````#0_0$```````($```(``````````````#8
M_0$```````($```)``````````````#@_0$```````($```+````````````
M``#H_0$```````($```,``````````````#P_0$```````($```-````````
M``````#X_0$```````($```.````````````````_@$```````($```/````
M```````````(_@$```````($```1```````````````0_@$```````($```2
M```````````````8_@$```````($```3```````````````@_@$```````($
M```4```````````````H_@$```````($```5```````````````P_@$`````
M``($```6```````````````X_@$```````($```7``````````````!`_@$`
M``````($```8``````````````!(_@$```````($```:``````````````!0
M_@$```````($```;``````````````!8_@$```````($```=````````````
M``!@_@$```````($```>``````````````!H_@$```````($```?````````
M``````!P_@$```````($```@``````````````!X_@$```````($```B````
M``````````"`_@$```````($```C``````````````"(_@$```````($```F
M``````````````"0_@$```````($```G``````````````"8_@$```````($
M```H``````````````"@_@$```````($```I``````````````"H_@$`````
M``($```J``````````````"P_@$```````($```K``````````````"X_@$`
M``````($```L``````````````#`_@$```````($```M``````````````#(
M_@$```````($```N``````````````#0_@$```````($```O````````````
M``#8_@$```````($```P``````````````#@_@$```````($```Q````````
M``````#H_@$```````($```R``````````````#P_@$```````($```S````
M``````````#X_@$```````($```T````````````````_P$```````($```U
M```````````````(_P$```````($```V```````````````0_P$```````($
M```W```````````````8_P$```````($```X```````````````@_P$`````
M``($```Y```````````````H_P$```````($```Z```````````````P_P$`
M``````($```[```````````````X_P$```````($```\``````````````!`
M_P$```````($```^``````````````!(_P$```````($```_````````````
M``!0_P$```````($``!```````````````!8_P$```````($``!!````````
M``````!@_P$```````($``!"``````````````!H_P$```````($``!#````
M``````````!P_P$```````($``!%``````````````!X_P$```````($``!'
M``````````````"`_P$```````($``!(``````````````"(_P$```````($
M``!*```````````````?(`/5_7N_J?T#`)&B`0"4_7O!J,`#7]8`````````
M`/![OZGP``#0$=9&^1"B-I$@`A_6'R`#U1\@`]4?(`/5\```T!':1OD0PC:1
M(`(?UO```-`1WD;Y$.(VD2`"'];P``#0$>)&^1`"-Y$@`A_6\```T!'F1OD0
M(C>1(`(?UO```-`1ZD;Y$$(WD2`"'];P``#0$>Y&^1!B-Y$@`A_6\```T!'R
M1OD0@C>1(`(?UO```-`1]D;Y$*(WD2`"'];P``#0$?I&^1#"-Y$@`A_6\```
MT!'^1OD0XC>1(`(?UO```-`1`D?Y$`(XD2`"'];P``#0$09'^1`B.)$@`A_6
M\```T!$*1_D00CB1(`(?UO```-`1#D?Y$&(XD2`"'];P``#0$1)'^1"".)$@
M`A_6\```T!$61_D0HCB1(`(?UO```-`1&D?Y$,(XD2`"'];P``#0$1Y'^1#B
M.)$@`A_6\```T!$B1_D0`CF1(`(?UO```-`1)D?Y$"(YD2`"'];P``#0$2I'
M^1!".9$@`A_6\```T!$N1_D08CF1(`(?UO```-`1,D?Y$((YD2`"'];P``#0
M$39'^1"B.9$@`A_6\```T!$Z1_D0PCF1(`(?UO```-`1/D?Y$.(YD2`"'];P
M``#0$4)'^1`".I$@`A_6\```T!%&1_D0(CJ1(`(?UO```-`12D?Y$$(ZD2`"
M'];P``#0$4Y'^1!B.I$@`A_6\```T!%21_D0@CJ1(`(?UO```-`15D?Y$*(Z
MD2`"'];P``#0$5I'^1#".I$@`A_6\```T!%>1_D0XCJ1(`(?UO```-`18D?Y
M$`([D2`"'];P``#0$69'^1`B.Y$@`A_6\```T!%J1_D00CN1(`(?UO```-`1
M;D?Y$&([D2`"'];P``#0$7)'^1"".Y$@`A_6\```T!%V1_D0HCN1(`(?UO``
M`-`1>D?Y$,([D2`"'];P``#0$7Y'^1#B.Y$@`A_6\```T!&"1_D0`CR1(`(?
MUO```-`1AD?Y$"(\D2`"'];P``#0$8I'^1!"/)$@`A_6\```T!&.1_D08CR1
M(`(?UO```-`1DD?Y$((\D2`"'];P``#0$99'^1"B/)$@`A_6\```T!&:1_D0
MPCR1(`(?UO```-`1GD?Y$.(\D2`"'];P``#0$:)'^1`"/9$@`A_6\```T!&F
M1_D0(CV1(`(?UO```-`1JD?Y$$(]D2`"'];P``#0$:Y'^1!B/9$@`A_6\```
MT!&R1_D0@CV1(`(?UO```-`1MD?Y$*(]D2`"'];P``#0$;I'^1#"/9$@`A_6
M\```T!&^1_D0XCV1(`(?UO```-`1PD?Y$`(^D2`"'];P``#0$<9'^1`B/I$@
M`A_6``````````````````````````````````````````#]>[JIXP``T&/8
M1_G]`P"1\U,!J?5;`JGBAP.IXN,`D>$#`9'@3P"YX#,!D60`0/GD+P#Y!`"`
MTLK__Y?B``#00M!'^>```-``\$?YX0,"JOP,`)3@``#0`/1'^0``0#G`"0`T
M]```T)3.1_GS``#P@`)`N9/__Y<"*%(Y0@`?,@(H$CF``D"YCO__EP(H4CGT
M3T"Y0@``,@(H$CF`$@`1E`X`$0!\?9.:__^7YB-`^>,#`*IB(@*1X```\.5/
M0+D!``#PQP!`^2$@')$$/$#Y````\`!`')%G!`"I0P0`^60``:F_!`!Q#0D`
M5"$`@-(@#``1Q'AA^"$$`)%DV"#XOP`!:VS__U2E#``1=2("D7_8)?CB`Q0J
M`0``D`0`@-(A$".1H`Y`^<K^_Y?T`P`JP`0`-'4B`I'V4P&1H`Y`^4S__Y<`
M``#PX0,6J@!`$I&$``"4(`0`M',B`I%@#D#YL/[_EQ?__Y?@``"P`-A'^>(O
M0/D!`$#Y0@`!ZP$`@-+!!`!4]5M"J>`#%"KS4T&I_7O&J,`#7];R_O^7\P``
MT&(B`I%`#`#Y0`,`M/0``+"4SD?Y#___EX`"0+E!__^7']PH.:O__Q>@#D#Y
MO?[_E_0#`"K8__\7H`I`^6```+18!P"4W?__%^$#%JH```#P`&`0D5L``)2@
M"@#YX/K_M%`'`)35__\7A0"`4L#__Q<@`(!2O_[_EQ+__Y<?(`/5'R`#U1\@
M`]4?(`/5'R`#U1\@`]4?(`/5'R`#U1\@`]4?(`/5'0"`TAX`@-+E`P"JX0-`
M^>(C`)'F`P"1X```L`#\1_D#`(#2!`"`TDG__Y?0_O^7X```L`#41_E```"T
M@/[_%\`#7]8?(`/5'R`#U>```-````*1X0``T"$``I$_``#KP```5.$``+`A
MX$?Y80``M/`#`:H``A_6P`-?UN```-````*1X0``T"$``I$A``#+(OQ_TT$,
M@8LA_$&3P0``M.(``+!"Y$?Y8@``M/`#`JH``A_6P`-?UA\@`]7]>[ZI_0,`
MD?,+`/GS``#08`)".4`!`#7@``"P`-Q'^8```+3@``#0``1`^87^_Y?8__^7
M(`"`4F`"`CGS"T#Y_7O"J,`#7]8?(`/5'R`#U=S__Q<?(`/5'R`#U1\@`]7]
M>[RI_0,`D?-3`:F@!@"T]V,#J?<#`*K@``"P`/A'^1@`0/DX!@"T]5L"J?8#
M`:H5`(!2X`)`.1_T`'$$&$!ZP0(`5!,#0/G3`0"TM7Y`D_0#&*H?(`/5X@,5
MJN$#%ZK@`Q.J;_[_EX```#5@:G4X'_0`<0`"`%23CD#X\_[_M?5;0JGW8T.I
MX`,3JO-30:G]>\2HP`-?UO4#%ZJ@'D`X'_0`<0080'JA__]4M0(72^7__Q>`
M`AC+M08`D7,"%8L`_$.3P`(`N>`#$ZKS4T&I]5M"J?=C0ZG]>\2HP`-?UA,`
M@-+I__\7]V-#J1,`@-+F__\7_7NUJ>(``+!"V$?Y_0,`D?,+`/GAHP"1\P,`
MJD,`0/GC5P#Y`P"`THG^_Y<@`@`UX3M`N0(`E%(A#!02/Q!`<2000GJ@`0!4
MX0``L"'81_GC5T#Y(@!`^6,``NL"`(#2@0$`5/,+0/G]>\NHP`-?U@``@%+U
M__\7X`,3JD$`@%(S_O^7'P``<>`7GQKO__\77_[_EQ\@`]4?(`/5X0``L"'8
M1_G]>[2I_0,`D2(`0/GB7P#Y`@"`TL```+3S4P&I\P,`J@$`0#EA`0`U\U-!
MJ>```+``V$?YXE]`^0$`0/E"``'K`0"`TJ$(`%3]>\RHP`-?UO5;`JEA_O^7
M]`,`JF`&`+3@`Q2J]?W_EX`%`+0!3$`Y%4P`D3^X`'&!``!4H09`.0'__S0?
M(`/5`$Q`.1^X`'$@!0!4X`,3JHC^_Y?V`P"JX`,5JH7^_Y?``@`+``@`$0!\
M0),U_O^7Y0,5JN0#$ZH#``#P8Z`.D0(`@)+U`P"J(0"`4GW^_Y?@`Q6JX>,`
MD>[]_Y<?!``QH```5.!+0+D`#!02'Q!`<:`"`%3@`Q6JCOW_E^`#%:I0_O^7
MX`,4JLK]_Y?`^O^UX`,4JM?]_Y?@`Q.J[?W_E_-30:GU6T*IO___%Z`&0#D?
MN`!QP?K_5*`*0#G@^/\TT___%^`#%:JJ__^7[/__%_-3`:GU6P*I`O[_EQ\@
M`]4,"(+2_V,LR^,``+!CV$?YXO^!TOU[`*G]`P"1\U,!J?,#`*KT`P&J]5L"
MJ?7C`)'A`Q6J8`!`^>`?"/D``(#2````\`#`#I%Z_?^7'P``<<T``%0$!`!1
MX@,`*J#*9#@``P`UI`(`->```+``S$?Y``!`N?O]_Y?B`Q2JX0,3JH3]_Y?@
M``"P`-A'^>(?2/D!`$#Y0@`!ZP$`@-(!`P!4_7M`J0P(@M+S4T&I]5M"J?]C
M+(O``U_6X@,$*A\@`]56?$"3X`,5JN(#%JKA!8!2`/[_EZ#\_[3@``"P`,Q'
M^0``0+G?_?^7XP,6JN(#%:KA`Q.JO_W_E^/__Q?!_?^7_7NZJ?T#`)'S4P&I
M\P,`JO0#`:KU6P*I]V,#J>```+``V$?Y(0!`.0(`0/GB+P#Y`@"`TC_T`'&4
M%I2:X`,4J@3^_Y?V`P"JX5,!D>`#$ZKL_O^70`@`M/4#`*K]_?^7WP(`Z^D&
M`%3W5X"Y^```L!C[1_GW\GW38`)`.1_T`'$$&$!ZX`L`5.0#$ZH?(`/5@QQ`
M.'_T`'%D&$!ZH?__5(0`$\N$?$"3%0-`^<`*`)$```2+F_W_EZ!J-_B@`@"T
M`0-`^>`#$ZHC:'?X`11`.&$``#D_]`!Q)!A`>L```%0"%$`X8AP`.%_T`'%$
M&$!Z@?__5*$'@%(``(#2810`.()J8#AB:"`X``0`D:+__S7@``"P`-A'^>(O
M0/D!`$#Y0@`!ZP$`@-)A!P!4\U-!J?5;0JGW8T.I_7O&J,`#7]8!`(#2'R`#
MU8)J83BB:B$X(00`D:+__S7N__\7^```L!C[1_GY:P2I&@-`^4`#0/G`!`"T
MX`,:JA4`@%(?(`/5`8Q`^.(#%2JU!@`1H?__M4`,`!$`?'V3X0``T"*(0+D"
M`@`U(@"`4B*(`+E=_?^7^0,`JD`#`+2W?GV3X0,:JN(#%ZJ3_?^7&0,`^:`&
M`!'U5P"Y/]L@^/EK1*FG__\7X0,`JN`#&JKN_/^7``,`^?D#`*I``0"TMWY]
MD_3__Q<$`(#2J?__%P`"@-(5`(!2XO__%_EK!*DZ_?^7^6M$J;S__Q?]>[ZI
M_0,`D?,+`/GS``"P<\Y'^6`"0+E)_?^78`)`N4?]_Y?B``"P0NQ'^2,``/`!
M``#P8T`5D2$`#Y%D_?^78`)`N3[]_Y?S"T#Y!```\/U[PJB$`!R1XP,$J@(`
M`+`!``#P0H`PD2&`#Y$%`(!2^_S_%Q\@`]4?(`/5X```L`#,1_G]>[^I_0,`
MD0``0+DK_?^7_7O!J",``/#B``"P0NQ'^6-`%9$!``#P(0`/D4?]_Q<?(`/5
M'R`#U0P*A-+_8RS+X```L`#81_D!"(+2_7L`J?T#`)'S4P&I\^,`D?43`/GU
M8R&+`0!`^>$G$/D!`(#2BOS_E^0#`"H%``#P`P``\*7@#Y%C`!"1(@""TB$`
M@%+@`Q.J2?W_E^`#$ZKA`Q6J`@""TGG\_Y=@`_@W\P,`J@`$`!$`?$"3\/S_
ME_0#`*J@`@"T<WY`D^$#%:KB`Q.J@OS_EY]J,SC@``"P`-A'^>(G4/D!`$#Y
M0@`!ZP$`@-(!`0!4_7M`J>`#%*KS4T&I#`J$TO430/G_8RR+P`-?UM+\_Y<4
M`(#2\/__%\?__Q<?(`/5'R`#U0P<@M+_8RS+X@``L$+81_G]>P"I_0,`D?-3
M`:GS`P&JX5,!D?5;`JGU`P"J0`!`^>!O"/D``(#2````\`!@$)'\_?^7]`,`
MJN$%@%+@`Q6JX/S_EV`"`+3A`Q6J````\`"@$)'S_O^7X`,5JN$``+`AV$?Y
MXV](^2(`0/EC``+K`@"`TN$,`%3]>T"I#!R"TO-30:GU6T*I_V,LB\`#7];@
M`Q.JP_S_EQ8``/#!XA"1)/S_E_,#`*H`_?^T]V,#J1@``/#W8P.1&",1D?EK
M!*D9``#P.0,1D6`"0#F@!@`TM```M.$#$ZK@`Q2JI?S_EP`%`#3@`Q.JXOS_
MEP($`-'Z`P"J8@("BW\"`NNC``!4"@``%%_T'SA_`@+K@```5$``0#D?O`!Q
M8/__5.`#$ZK4_/^7^@,`JN`#%:K1_/^7```:BP`$`)$?_#_QR`(`5.0#$ZKF
M`Q6JY0,9JN,#&*H"`(+2(0"`4N`#%ZK)_/^7X6,!D>`#%ZHZ_/^7H```->!K
M0+D`#!02'R!`<8`"`%3!XA"1``"`TNK[_Y?S`P"JP/G_M?=C0ZGY:T2IJ___
M%Q0#`+2``D`Y'[@`<:```%03``#P.@"`TG-"$)';__\7@`9`.>#]_S3Z__\7
MX`,7JB$`@%(C_/^70/W_->$#%ZH```#P`*`0D8[^_Y?@`Q>J;/S_E_=C0ZGY
M:T2IF/__%Q,``/`Z`(#2<T(0D<?__Q?W8P.I^6L$J4+\_Y<?(`/5_7N^J>$%
M@%+]`P"1\PL`^?,#`*KK^_^7'P``\6`&@)KS"T#Y_7O"J%;\_Q<?(`/5#`B"
MTO]C+,OA``"P(=A'^?U[`*G]`P"1(@!`^>(?"/D"`(#2``8`M/43`/GU`P"J
M`0!`.6$%`#3S4P&I>?S_EP($`)'S`P"J7P1`\:@&`%3TXP"1X0,5JN`#%*J]
M^_^78`8`T8`"`(L?`!3KJ```5`<``!0?]!\X'P`4ZX```%0!`$`Y/[P`<6#_
M_U3@`Q2JX06`4K_[_Y>`!`"T'P`4Z\@#`%3@`Q2J*OS_E^$``+`AV$?YXQ](
M^2(`0/EC``+K`@"`TJ$$`%3]>T"I#`B"TO-30:GU$T#Y_V,LB\`#7];U$T#Y
MX```L`#81_GB'TCY`0!`^4(``>L!`(#2`0,`5````/``0!"1_7M`J0P(@M+_
M8RR+#_S_%Q\``#GB__\7``"`TN+__Q?@``"P`-A'^>(?2/D!`$#Y0@`!ZP$`
M@-+!``!4\U-!J0```/#U$T#Y`$`0D>W__Q?>^_^7\U,!J?43`/G;^_^7'R`#
MU1\@`]7]>[JIX```L`#81_G]`P"1\U,!J10``/#S4P&1]5L"J91"$9'W8P.I
M^2,`^?4``+"U^D?Y`0!`^>$O`/D!`(#2X0,3JN`#%*H&_?^7X`$`M*("0/GC
M5X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A`Q.JX`,4JOC\
M_Y=@_O^U]0``L+7Z1_D4``#PE((1D>$#$ZK@`Q2J\/S_E^`!`+2B`D#YXU>`
MN4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#%*KB_/^7
M8/[_M?4``+"U^D?Y%```\)2B$9'A`Q.JX`,4JMK\_Y?@`0"TH@)`^>-7@+E`
M#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@`Q2JS/S_EV#^
M_[7U``"PM?I'^10``/"4XA&1X0,3JN`#%*K$_/^7X`$`M*("0/GC5X"Y0`P#
MBP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A`Q.JX`,4JK;\_Y=@_O^U
M]@``L-;Z1_D4``#PE0(2D>$#$ZK@`Q6JKOS_E^`!`+3"`D#YXU>`N4`,`XL!
M!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#%:J@_/^78/[_M?8`
M`)#6^D?Y%0``T+5"$I'A`Q.JX`,5JIC\_Y?@`0"TP@)`^>-7@+E`#`.+`01`
M^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@`Q6JBOS_EV#^_[7W``"0
M]_I'^14``-"V8A"1X0,3JN`#%JJ"_/^7X`$`M.("0/GC5X"Y0`P#BP$$0/E!
M>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A`Q.JX`,6JG3\_Y=@_O^U^```D!C[
M1_D6``#0UX(2D>$#$ZK@`Q>J;/S_E^`!`+0"`T#YXU>`N4`,`XL!!$#Y07@C
M^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#%ZI>_/^78/[_M?D``)`Y^T?Y
M%P``T/C"$I'A`Q.JX`,8JE;\_Y?@`0"T(@-`^>-7@+E`#`.+`01`^4%X(_CA
M_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@`QBJ2/S_EV#^_[7Y``"0.?M'^1@`
M`-`8`Q.1X0,3JN`#&*I`_/^7X`$`M"(#0/GC5X"Y0`P#BP$$0/E!>"/XX?[_
MM`$(0/D!!`#Y`"``D:'__[7A`Q.JX`,8JC+\_Y=@_O^U^0``D#G[1_D8``#0
M&*,0D>$#$ZK@`QBJ*OS_E^`!`+0B`T#YXU>`N4`,`XL!!$#Y07@C^.'^_[0!
M"$#Y`00`^0`@`)&A__^UX0,3JN`#&*H<_/^78/[_M>$#$ZH```#0`$`3D1?\
M_Y?A`P"J8```M.#"$I$3_?^7X0,3J@```-``H!.1#_S_E^$#`*J```"T````
MT```%)$*_?^7X0,3J@```-``0!21!OS_E^$#`*I@`@"TH&(0D0+]_Y?@``"0
M`-A'^>(O0/D!`$#Y0@`!ZP$`@-)A`@!4]5M"J8`"$I'S4T&I`0``T/=C0ZDA
MX!21^2-`^?U[QJCR_/\7X0,3J@```-``@!21[OO_E^$#`*I@_?^TP((2D>K\
M_Y?H__\7J/K_E_U[O:G]`P"1X0``D"'81_GS"P#Y\P``L"(`0/GB%P#Y`@"`
MTF`20+D?!``Q8`$`5.$``)`AV$?YXQ=`^2(`0/EC``+K`@"`TB$"`%3S"T#Y
M_7O#J,`#7];ADP"1````T`"`$I'.^_^7X0,`J@``@%*A``"T(`!`.1_``'$$
M&$!ZX`>?&F`2`+GJ__\7A/K_E_U[OZG]`P"1:?K_EQ3Z_Y=```"T``!`^?U[
MP:C``U_6_7N\J>$``)`AV$?Y_0,`D?-3`:GT`P"J]5L"J14``-"V`A61(@!`
M^>(?`/D"`(#2X`,6JN'3`)&M^_^7@```M`$`0#GS`P"JP0$`->```)``V$?Y
MXA]`^0$`0/E"``'K`0"`TB$&`%3A`Q2JH`(5D?-30:GU6T*I_7O$J)S\_Q?A
M`Q2J%OK_EX`!`+3@``"0`-A'^>(?0/D!`$#Y0@`!ZP$`@-(A!`!4\U-!J?5;
M0JG]>\2HP`-?UN`#%*J@^O^7]0,`JN`#$ZJ=^O^7H`(`BP`(`)%.^O^7Y@,3
MJ@(`@)(A`(!2Y`,4JO,#`*H%``#0`P``T*7@$)%C(!&1E/K_E^```)``V$?Y
MXA]`^0$`0/E"``'K`0"`TH$``%3A`Q.JX`,6JM/__Q<Q^O^7##:0TO]C+,OA
M``"0(=A'^?U[`:G]0P"1]5L#J?8``+#"0@"10X``D?-3`JGU`P"J1IQ`J?=C
M!*GT\P&11!1%J?EK!:GYPP*18`1`K1<``-!B",`]XR-`D2``0/E@U`#Y``"`
MTN$#%*I##$#YX&(0D4(P0/D@!P"MYA\(J>-+`/GDEPFIXE<`^>(W@#U-^_^7
M@```M`$`0#GS`P"J`2$`-?MS!JGO^?^7FOG_ER`0`+0:`$#Y^@\`M.`#&JI5
M^O^7`/A_TP`$`)$&^O^7\P,`JD0#0#GX`P"JA`$`-!L``-![8Q61'R`#U>`#
M$ZKC`QNJ`@"`DB$`@%)*^O^7<PH`D40?0#@D__\U````T#DC`)$``!21`P``
M%""'0/B@`0"TX0,4JB?[_Y?S`P"J8/__M`$`0#DA__\T7_O_E^#^_S3@`Q.J
M__G_E_,#`*J@`0"U^0,"D3,#0/E3`0"T8`)`.4`*`#3@`Q.J4_O_ER`)`#4S
M!T#Y.2,`D3/__[4?(`/5X`,3JB/Z_Y?Z`P"JX`,8JB#Z_Y=;`P`+>Q,0$1D`
M`-![?T"3X`,;JL[Y_Y?G`QBJY`,3JB4#$9$&``#0`P``T,:`%9%CH!61`@"`
MDOH#`*HA`(!2$_K_E^`#&JH!.(!2Z/G_EQ\$`#&A``!4H?G_EP4`0+F_1`!Q
MX10`5.&#`Y'@`QJJO_G_E_,#`"J@```UX/-`N0`,%!(?$$!Q``@`5.```)``
MZ$?Y`@``T*,"0/GD`QJJ``!`^4+@%I$A`(!2F/G_EQ@`@-+@``"0`-A'^>(C
M0)%#U$#Y`0!`^6,``>L!`(#2028`5/U[0:G@`QBJ\U-"J0PVD-+U6T.I]V-$
MJ?EK1:G[<T:I_V,LB\`#7];@`Q.J.2,`D:KY_Y?S`P"JH/7_M+?__Q<3`(#2
MM?__%^!/0/GS8P*10`$`M!\@`]7A`Q2JO_K_EV```+0!`$`Y@0$`-6`&0/ES
M(@"1(/__M:`!@-)_^?^7&@``T/,#`*I:0Q61^`,`JF0*@%)X__\7D/G_E_H#
M`*I@_O^TP?G_EP#X?],`!`"1;/__%_C[0+E0^?^7'P,`:\'W_U3@\T"Y`"``
M$A\`!W%!]_]4X`,;JFCY_Y<!``#0^`,`JB!`&)'A`Q2JF_K_E^$#`*I`&`"T
MH`)`^8O\_Y?\`P"JP!<`M.`#'*JG^?^7^P,`JA\,`''-`0!4`'Q`DP$``-``
M$`#1(6`8D8`#`(M>^?^7X```-7\3`'%`%@!4>Q<`48#+>S@?O`!QP!4`5,`2
M0+D?!``Q(`H`5&`+`#0!``#0````T"'@%)$`@!*1>OO_ESD#$9$4``#0E`(<
MD<;X_Y<5``#0Y@,`*N<#%*KE`QFJY`,:JN`#&*H#``#0`@"`DF/@&)$A`(!2
MM2(9D8+Y_Y<1```4%/G_EP``0+D?1`!Q00(`5+3X_Y?T`P#Y<P8`$>8#`"KG
M`Q,JY0,9JN0#&JKC`Q6JX`,8J@(`@)(A`(!2<?G_E^`#&*H!.(!21OG_EQ\$
M`#&`_?]4X`,:JDKY_Y?A`QBJX&(0D4_[_Y?@`QBJDO[_EV[__Q?@``"0`.A'
M^>0#&JJC`D#Y`@``T```0/E"X!61(0"`4OOX_Y=C__\7AO[_E^```)``V$?Y
MXB-`D4/40/D!`$#Y8P`!ZP$`@-*A$@!4_7M!J>`#$ZKS4T*I##:0TO5;0ZGW
M8T2I^6M%J?]C+(L0^?\7````T.$#%*H`@!*1+/K_EX`,`+0``$`Y'\``<008
M0'K@!Y\:P!(`N>#T_S7@`QRJ`0"`4C+Y_Y?T`P`J0/3_-$(`@%(A`H"2\Z,&
MD5SX_Y?A`Q.JX`,4*L(`@-+,^/^7X*-&.8```#7@IT8Y'PP!<<`)`%0"`(!2
M`0"`TN`#%"I/^/^7@@4`E/4#`*H%```4X@,`*N$#$ZK@`Q6JC`4`E.$#$ZK@
M`Q0J`@"0TKCX_Y<?``!Q[/[_5.`#%"KS@P61!_G_E_SC!9'A`Q6J&P``T/4#
M$ZKT`QRJEJ,`D7MC%9'@`Q.JO@4`E!\@`]6D%D`XX`,4JN,#&ZJ4"@"1`@"`
MDB$`@%(&^?^7GP(6ZP'__U3F`QRJ)0,1D>0#&JH'``#0`P``T.<`')%CH!B1
M`@"`DB$`@%+@`QBJ_X,&.?CX_Y?@`QJJUOC_E^$#&*K@8A"1V_K_E^`#&*H>
M_O^7^O[_%[P"0/E"__\7M09`^57J_[3@`Q6JYOC_EQ\,`/')Z?]4`!``T0$`
M`-"@`@"+(8`8D9_X_Y<?``!QG!.5FD;__Q??$@"YHO__%^"K1CD?!`%Q(?;_
M5."O1CD?#`%QP?7_5."S1CD?(`%Q8?7_5."W1CD?%`%Q`?7_5.`#%"I"`(!2
M(0>`DO;W_Y?A`Q.JX`,4*B(%@-)F^/^7Y@,3JB4#$9'D`QJJX`,8J@<``-`#
M``#0YP`<D6.@&)$"`("2(0"`4K_X_Y=3__\79?C_E_MS!JEC^/^7'R`#U1\@
M`]7]>[NI_0,`D?-3`:GS``"0<\Y'^?5;`JGV$P&1X0``D"'81_GW&P#Y8`)`
MN2(`0/GB)P#Y`@"`TFKX_Y?T`P"J8`)`N6?X_Y?B`P"J@\)".0```-#A`Q:J
M```2D4/$`CF(^?^7@```M`$`0#D_Q`!Q(`L`5&O\_Y=@`D"Y6?C_EP$``-!C
M`(!2(8`9D2(`@%+8]_^7]`,`JH`!`+1@`D"Y4/C_EX$*0/D"``#00J`9D2$`
M0/G7]_^7@`I`^0``0/D`#$"YX`JP-V`"0+GU``"P1/C_EP$``-!C`(!2(<`9
MD2(`@%+#]_^7]`,`JJ`!`+3A`Q:J````T`"@$)%A^?^7]P,`JF`"0+G7!P"T
M-?C_EX$*0/GB`Q>J(0!`^;WW_Y=@`D"YMR("D2[X_Y?T`P"J8`)`N2OX_Y<B
M`(!2`0``T"'@&9&']_^7`@``T.$#`*I"0!J1X`,4JJ[W_Y=@`D"Y(/C_E^(#
M`*KA`Q:J````T`!@$)%?Q`(Y0OG_E^`*`/GS`P"JX`(`M`$X@%+@`Q.J+/C_
MEP$$`!$_!`!Q!(A1>N$$`%3@``"0`-A'^>(G0/D!`$#Y0@`!ZP$`@-+A`P!4
M\U-!J?5;0JGW&T#Y_7O%J,`#7]8`!$`Y`/7_-*;__Q?@!D#YM_W_E^`*`/GS
M`P"JP/S_M0```-``8!J1!?C_E_CW_Y>@(@*1@@I`^0$$0/E``$#Y(0!`^=KY
M_Y?!__\78`)`N>_W_Y>!"D#Y(0!`^>#W_Y>E__\7TO?_E[4B`I'C`P`JX@,3
MJ@```-```!N1H09`^2$`0/GN]_^7'R`#U?U[O*GA``"0(=A'^?T#`)'S4P&I
M\P,`JO5;`JGU``"P(@!`^>(?`/D"`(#2B?O_E_0#`*KA!8!2:O?_EQ\``/&`
M!H":U_?_E_8#`*JA$D"Y?P(`\?0'GQH_!``Q@`0`5#\``''@!Y\:E`(`"I0!
M`#7@``"0`-A'^>(?0/D!`$#Y0@`!ZP$`@-(A!0!4\U-!J?5;0JG]>\2HP`-?
MUF`"0#F`_O\T`0``T.`#%JHA@!61@@"`TF/W_Y?`_?\UX```D`#81_GB'T#Y
M`0!`^4(``>L!`(#2P0(`5/5;0JG@`Q.J\U-!J?U[Q*@R^?\7````T.'3`)$`
M@!*1ROC_ET`!`+0!`$`Y/P``<>`'GQH_P`!QX0>?&@```0J@$@"Y%``4"M/_
M_Q>_$@"YTO__%WWW_Y?_@PK1`>``D>,``)!CV$?YXD,`D?U[`*D$X`&1_0,`
MD5'D`&_PY0!O90!`^>5/`?D%`(#2A^0`;^,#`JHC`$!M(@3!/&,X@`Y!!&!O
M0`18;V,(("Y"!$AO)E183P`<,4YDI"`O(51(3\,<,$X`'*).(1PG3@`<HTX%
M'*%.9(R?3)\``>O!_?]4\!]!K4*@"9'F#T*MX>,!D>430ZWA(\`]\>4`;Q\@
M`]4B@-D\(4``D2``WSP`'")N`!PC;@`<,&[P'*=.QQRF3F8<HTX"5$%/``1A
M;Z,<I4Z%'*1.)!RA3D`<H$X!'#%.(8"`/#\``NO!_?]4!RA`J20SC](()$&I
M1%"K\N4_0:DC=)W2XOQ;T^S\0M-"%`>JC'D'JB$!",HCVZWR(0`*BB$`"<JE
M``2+(D`BBT']0M,+$$#Y(7@*JBU\0))"``6+I0$(RD(`"POF0T*II0`'BJ4`
M",KO`02+3OQ;TZ4`"8O.%0*J(0`,RJ4`#XLA``**I0`."T_\0M,A``W*XGD"
MJL8`!(NN_%O3(0`(B\X5!:HA``:+A@$"RB$`#@N,?4"2Q@`%BJ[\0M/&``S*
M$`($B\8`#8LO_%O3S7D%JN\5`:KN&T#Y10`-RL8`$(M"?$"2Q@`/"Z4``8JE
M``+*,/Q"T\X!!(NE``R+S_Q;TPQZ`:KO%0:JI0`.BZ4`#PNA`0S*S_Q"TR$`
M!HKF>0:JK7U`DNZ_0ZDA``W*(0`"B[#\0M/"`02+KOQ;TR$``HN"`0;*0@`%
MBHQ]0)+.%06J0@`,RBX`#@L%>@6JX0$$BT(`#8M"``&+P0`%RM!\0)(A``Z*
M(0`0RLW]6],A``R+K14.JN^S1*E-``T+QOU"T\YX#JJF?$"2X@$$BZ_]6],A
M``*+H@`.RN\5#:I"``V*+P`/"Z7]0M-"``;*@0$$BZ5X#:I"`!"+0@`!B^S]
M6]/!`07*\/U"TXP5#ZHA``^*#WH/JDP`#`OMPT6ISGU`DB$`#LHA``:+AOU;
MT\84#*JB`02+$`($BR$``HNB``_*+0`&"Z5\0))"``R*AOU"TT(`!<K&>`RJ
MH?U;TT(`#HM"`!"++!0-JK#]0M/A`0;*(0`-B@UZ#:KNPT:I3``,"^]]0)(A
M``_*(0`%BX7]6].E%`RJP@$$BQ`"!(LA``*+P@`-RBX`!0O&?$"20@`,BH7]
M0M-"``;*I7@,JL']6]-"``^+0@`0BRP4#JK0_4+3H0$%RB$`#HH.>@ZJ[\-'
MJ4P`#`NM?4"2(0`-RB$`!HN&_5O3QA0,JN(!!(L0`@2+(0`"BZ(`#LHO``8+
MI7Q`DD(`#(J&_4+30@`%RL9X#*KA_5O30@`-BT(`$(LL%`^J\/U"T\$!!LHA
M``^*#WH/JNW#2*E,``P+SGU`DB$`#LHA``6+A?U;TZ44#*JB`02+$`($BR$`
M`HO"``_*+0`%"X7]0M.E>`RJ0@`,BJ']6]/&?$"2+!0-JN$!!<HA``V*[WU`
MDD(`!LHA``_*0@`.BR$`!HONFTFI0@`0BTP`#`NP_4+3#7H-JI#]0M/"`02+
MCOU;TR$``HO.%0RJH@`-RBX`#@NE?$"20@`,BD(`!<H,>@RJP0`$BT(`#XO&
M_5O30@`!B^]70/FA`0S*QA0.JJU]0)+2``(+(0`.BB$`#<KD`02+(0`%B]#]
M0M-%_EO3#GH.JN];0/DA``2+I102JD9`)HNP``$+A`$.RH0`!DKB`0.+A``-
MBP;^6]--_D+3A``"B^)?0/FR>1*JQA00JB5`)8O/``0+P0$2RB4`!4I!``.+
MHD`LBPS^0M/E_5O3C7D0JD(``8NE%`^JX6-`^;$``@N&0":+1`(-RH0`!DKL
M_4+3)@`#BX%`+HLD_EO3CWD/JB$`!HN$%!&JYF=`^9```0M%0"6+H@$/RD4`
M!4HN_D+3T7D1JJQ`,HO"``.+!?Y;T^9K0/F"`0*+I100JB1`)(OA`1'*K@`"
M"R0`!$H,_D+3P0`#BX9`+8N0>1"JP0`!B^9O0/G$_5O314`EBX04#JHB`A#*
MC0`!"T(`!4K&``.+0D`OB\S]0M..>0ZJ0@`&B^9S0/FE_5O3I10-JB1`)(L!
M`@[*KP`""R$`!$JL_4+3C7D-JL8``XLA0#&+Y/U;TR$`!HM%0"6+YG=`^<(!
M#<J$%`^J10`%2I$``0NL0#"+\/U"T\(``XOF>T#Y#WH/JB7^6],D0"2+H0$/
MRH(!`HNE%!&J)``$2K```@O!``.++/Y"TX9`+HN,>1&JP0`!B^9_0/E%0"6+
M!/Y;T^(!#,J$%!"J0@`%2HX``0O&``.+0D`MBPW^0M/Q@T#Y0@`&BZ9Y$*HD
M0"2+Q?U;TX$!!LJE%`ZJ(0`$2JT``@LP`@.+(4`OB\_]0M,A`!"+[GD.JO"'
M0/FD_5O3A!0-JD5`)8NQ_4+3P@`.RH\``0LM>@VJ10`%2@("`XOPBT#Y)$`D
MB\$!#<JL0"R+)``$2N7]6].E%`^JAD`FB_']0M,!`@.+P0`!BX(!`HLF>@^J
MK``""T5`)8NB`0;*0@`%2H3]6]-"0"Z+A!0,JO"[4:F1_4+3CP`!"RQZ#*HD
M0"2+P0`,RN7]6],A``1*\?U"TZ44#ZH0`@.++WH/JD(`$(LA0"V+[<=2J;``
M`@O.`0.+14`EBP3^6],A``Z+A!00JH(!#\J.``$+0@`%2D)`)HNE`0.+#?Y"
MTT4`!8O&_5O3HGD0JL84#JHD0"2+X0$"RLT`!0LD``1*(0(#BX1`+(O1_4+3
M\)]`^80``8NL_5O3(7H.JHP5#:JF0":+10`!RHX!!`NE``9*$`(#BZ5`+XNO
M_4+3[WD-JJ4`$(OPHT#YQOU;T\84#JJ,0"R+)``/RLT`!0N,``Q*T?U"TP0"
M`XN"02*+L/U;TT(`!(LD>@ZJID`FB^RG0/D0%@VJY0$$RD(`$`NE``9*KOU"
MTZ%`(8O%>0VJA@$#BT[\0M.,``6J0_Q;TV,4`JJ,`0**PGD"JB$`!HOM.U6I
M(0`#"Z,`!`J&FY?2C`$#JF;CL?*#02^++_Q"TZP!!HLM_%O3K14!JF,`#(NL
M``*J8P`-"XP!`8I-``4*C`$-JN%Y`:K.`0:+A$$DBVW\6]-,``&JK14#JH0`
M#HN$``T+C`$#BBT``@IN_$+3C`$-JHW\6].%026+S'D#JN\[5JFC%02J+0`,
MJN\!!HO.`0:+I0`/BX_\0M.C``,+I0$$BHT!`0JE``VJ;?Q;TZ5`(HOB>02J
MK14#JH0!`JJE``Z+A``#BJ4`#0M-``P*A``-JFW\0M.$0"&+H7D#JN\W5ZFN
M_%O3SA4%JD,``:IC``6*[P$&BZT!!HN$``^+K_Q"TX0`#@LN``(*8P`.JN5Y
M!:IC0"R+COQ;T\X5!*HL``6J8P`-BXP!!(KMPT#Y8P`."ZX``0J/_$+3C`$.
MJN1Y!*J"02*+;OQ;TZP!!HO.%0.J[<=`^4(`#(NL``2J0@`."XP!`XJ.``4*
MC`$.JF_\0M/C>0.JK0$&BX%!(8M._%O3SA4"JHP``ZHA``V+C`$"BB$`#@MN
M``0*C`$.JD[\0M/">0*JA4$EB^T[6:DO_$+3K`$&BRW\6].M%0&JI0`,BVP`
M`JJE``T+C`$!BDT``PJ,`0VJX7D!JLX!!HN$022+K?Q;TTP``:JM%06JA``.
MBX0`#0N,`06*+0`""J[\0M.,`0VJC?Q;TX-!(XO,>06J[SM:J:T5!*HE``RJ
MI0`$BN\!!HO.`0:+8P`/BX_\0M-C``T+C0$!"J4`#:KD>02JHD`BBVW\6].M
M%0.JA0$$JD(`#HNE``.*0@`-"XT`#`JE``VJ;?Q"TZ%`(8NE>0.J[S=;J4[\
M6]/.%0*J@P`%JF,``HKO`0:+K0$&BR$`#XNO``0*(0`."V,`#ZI._$+3;$`L
MB\)Y`JHC_%O3C`$-BV,4`:JM``*J+_Q"TX,!`PNL`0&*X7D!JDT`!0KN/URI
MC`$-JH1!)(MM_%O3K14#JLP!!HLN``(*A``,BTP``:J$``T+C`$#BHP!#JIM
M_$+3K7D#JN\!!HN%026+COQ;T^SK0/FC``^+SA4$JB4`#:IC``X+I0`$BJX!
M`0J/_$+3I0`.JF[\6].B0"*+A0$&B^1Y!*K.%0.J0@`%BZ4!!*I"``X+;OQ"
MTZ4``XK#>0.J[+M=J8\`#0JE``^J3_Q"TZ5`(8M!_%O3(10"JHP!!HNE``R+
MC``#JJ4``0N,`0**80`$"N)Y`JJ,`0&J4``#"H%!+8O-`0:+K/Q;TR$`#8OO
M]T#Y;0`"JHP5!:JM`06*C@$!"ZT!$*JD022+L/Q"T^T!!HO&_5O3[_M`^80`
M#8O&%`ZJ#7H%JM$`!`LL0"R+00`-RL4ZF-(A``Q*14RY\B%`(XOL`06+T/U"
MTR/^6]/O_T#Y#GH.JF,4$:HA``R+;``!"X9`)HND`0[*(T`CBX0`!DKF`06+
M@D`BBR_^0M.$_5O3\7D1JD(`!HN$%`RJY@-!^9(``@O!`1'*1$`DBR,``TK!
M``6+9D`MBXW]0M-#_EO3L'D,JL8``8MC%!*JX0=!^6\`!@LB`A#*3/Y"TT(`
M!$HD``6+0D`NB^']6].->1*J1``$B^(+0?DA%`^J+@`$"\-`(XL&`@W*[/U"
MT\,``TI&``6+8T`QB\+]6]./>0^J8P`&B^8/0?E"%`ZJ40`#"X%`(8ND`0_*
M8D`BBX$``4K$``6++$`PB]#]0M,A_EO3#GH.JN830?F$`02+(101JN,!#LHP
M``0+8@`"2BS^0M/#``6+1D`MBP+^6].,>1&JPP`#B^870?E"%!"J30`#"X%`
M(8O$`0S*$?Y"TX$``4K&``6+)$`OBZ']6]/O&T'YA``&BR$4#:HF>A"J8D`B
MBS``!`N#`0;*[P$%BV(``DJQ_4+30T`NBP+^6]/N'T'Y+7H-JF,`#XM"%!"J
M3P`#"X%`(8O$``W*8D`BBX$``4K$`06++$`LBP[^0M/A_5O3T'D0JH0!!(LA
M%`^J["-!^3$`!`NC`1#*@4`ABV(``DJ#`06+1D`FB^S]0M,B_EO3CWD/JL,`
M`XM"%!&JYB=!^4X``PL$`@_*8D`BBX$``4K&``6+)$`MBRW^0M/!_5O3A``&
MB^PK0?FF>1&J(10.JN,!!LHM``0+8@`"2HP!!8M#0#"+T/U"TZ+]6],.>@ZJ
M8P`,B^PO0?E"%`VJ40`#"X%`(8O$``[*8D`BBX$``4J$`06++$`OBZ_]0M,A
M_EO3[7D-JH0!!(LA%!&J[#-!^3``!`O#`0W*+_Y"TV(``DJ,`06+0D`FBP/^
M6]-&``R+8Q00JN(W0?GL>1&J@4`ABV\`!@ND`0S*PT`CBX0``4I!``6+A$`N
MB^+]6],._D+3A``!B_$[0?G!>1"J0A0/JH8!`<I.``0+PP`#2C`"!8MF0"V+
M\?U"T\/]6]/M/T'Y8Q0.JB]Z#ZK&`!"+<``&"X)`(HLD``_*QD`CBX0``DJB
M`06+C$`LB\W]0M,$_EO3C`$"B^)#0?F$%!"JKGD.JH,`#`OM`0[*YT`OBZT!
M!DI&``6+H4$ABV+\6]-"%`.J(0`&B^U'0?DA``(+`OY"TX9!)(M">!"J)/Q;
MT\P!`LJ$%`&JC`$&2J8!!8ME_$+3Q@`'BZ-X`ZJ$``R+QP``T.?81_DA``H+
M0@`)"\4!"PN$``8+8P`("P0$`*D#"`&I!1``^>)/0?GA`$#Y0@`!ZP$`@-*!
M``!4_7M`J?^#"I'``U_63_/_EQ\@`]4?(`/5_7N_J0`0@-+]`P"14?/_EQ\8
M`/DB``"0(0``D!]X`+E!7,$](@``D")8P3U`8,$]`@0`K0`(@#W]>\&HP`-?
MUOU[O*E"?$"3_0,`D?-3`:D4X`"1\P,!JO5;`JGU`P"J]@,"JO=C`ZD%C$*I
M`'A`N:0,`@N_``3K8Y2#FF)T0HNDB@*IH`,`-=_^`'&M!0!4U@(!4=A^!E,7
M!P`1]VIZTW<"%XL?(`/58`9`K>`#%:J`!@"M8`9!K7,"`9&`!@&MH/O_EW\"
M%^L!__]4UAH82^$#%ZK@`Q2JPGY`D[7R_Y>V>@"Y\U-!J?5;0JGW8T.I_7O$
MJ,`#7]87"(!2]P(`2_\"%FN`PB"+]]*6&OA^0)/B`QBJI_+_EZ!Z0+G@`@`+
MH'H`N1\``7'A_?]4U@(72W,"&(O@`Q6J@OO_E]/__Q?W`Q.JX___%Q\@`]4?
M(`/5_7N\J>(/@!+]`P"1\U,!J?0#`*KS`P&J]5L"J3;@`)'H&P#]-11`^2@8
M0/V@(@-3`00`$<+*(#C`PB&+/^``<4T+`%0""(!20@`!2P$`@%)"?$"3/_/_
ME^`#$ZIE^_^7?S8`^0`$`$_``@"MP`J`/04%<'\`!6A_!`5X?Z$"9Y[@`Q.J
M(P1H?R($<'^@!`-N(01X?X`$!6X`!0=N8`0);D`$"VX@!`UNH!X/3F`Z`/U0
M^_^780)`^>`#$ZHA_%C3@0(`.6$"0/DA_%#3@08`.6$"0/DA_$C3@0H`.6$"
M0/F!#@`Y809`^2'\6-.!$@`Y809`^2'\4-.!%@`Y809`^2'\2-.!&@`Y809`
M^8$>`#EA"D#Y(?Q8TX$B`#EA"D#Y(?Q0TX$F`#EA"D#Y(?Q(TX$J`#EA"D#Y
M@2X`.6$.0/DA_%C3@3(`.6$.0/DA_%#3@38`.6$.0/DA_$C3@3H`.6$.0/F!
M/@`Y81)`^2'\6-.!0@`Y81)`^2'\4-.!1@`Y81)`^2'\2-.!2@`Y81)`^8%.
M`#GS4T&I]5M"J>@;0/W]>\2HQ_+_%P('@%)"``%+`0"`4D)\0)/F\O^7K?__
M%\,``/!C!$#Y=O+_%Q\@`]7]>[^I_0,`D?U[P:C``U_6`0`"```````E<R\E
M<P```"]P<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D
M97(``````$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````&5X90``````+W!R;V,O
M)6DO)7,``````"X`````````4$%27U1%35```````````%!!4E]04D]'3D%-
M10`````Z`````````"\`````````)7,E<R5S``!015),-4Q)0@``````````
M4$523$Q)0@!015),-4]05```````````4$523$E/``!005)?24Y)5$E!3$E:
M140`4$%27U-005=.140``````%!!4E]#3$5!3@````````!005)?1$5"54<`
M````````4$%27T-!0TA%`````````%!!4E]'3$]"04Q?1$5"54<`````````
M`%!!4E]'3$]"04Q?5$U01$E2`````````%!!4E]435!$25(```````!005)?
M1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@``````````,0````````!,
M1%],24)205)97U!!5$@`4UE35$5-```E,#)X`````'!A<BT`````)7,E<R5S
M)7,``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T92!S=6)D
M:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R
M971R>2!Y;W5R(&]P97)A=&EO;BD*````````4$%42`````!P87)L`````"YP
M87(`````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M
M<"TE=2TE=25S```````````8`````````'!E<FP`````,`````````!005(Z
M.E!A8VME<CHZ5D524TE/3@`````Q+C`U-@```%5N86)L92!T;R!C<F5A=&4@
M8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@;V8@<')I=F%T
M92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````
M```````M90```````"TM````````55-%4@````!54T523D%-10``````````
M5$U01$E2``!414U01$E2`%1%35``````5$U0```````O=&UP`````&5V86P@
M)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C
M(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P
M;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D0T%#2$5?
M;6%R:V5R+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#
M(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P
M86-K*").(BD*)&-A8VAE7VUA<FME<B`](")<,$-!0TA%(CL*)&-A8VAE7VYA
M;65?<VEZ92`](#0P.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I
M(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM
M>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]("1S:7IE("T@)'-I>F4@)2`D
M8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O
M9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D
M<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H
M)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-
M04=)0RDI(#X](#`I('L*)'!O<R`K/2`D:3L*<F5T=7)N("1P;W,["GT*)'!O
M<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M
M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@
M:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@
M)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D[
M"F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL
M93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL
M:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P
M87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@
M1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I
M;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC
M;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL
M96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M
M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P
M87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X
M("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM
M;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E
M=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D
M(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE
M;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@
M:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R
M7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY
M("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G
M.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\
M3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H
M)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R
M;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D[
M"E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B
M)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I
M.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL
M97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;
M0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@
M=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)
M0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF
M("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@
M<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA
M<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N
M("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O
M9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S
M:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F
M9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?
M1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L
M(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR
M96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C
M(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I
M('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH
M(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A
M8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L
M;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM
M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI
M*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT
M("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?
M<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@
M*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[
M4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&)A<V5N
M86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE
M7&XB*3L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U
M9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT[
M"B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F
M+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE
M*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY
M("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S
M("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD
M;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM0
M05)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A
M=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT
M*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*
M?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C
M?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA
M;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q
M6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID
M:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D
M;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E
M(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP
M;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R
M="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL
M96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N
M86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS
M92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S
M=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N
M86UE?3L*?0IU;FQE<W,@*"1B=68@97$@(E!+7#`P,UPP,#0B*2!["F]U=',H
M<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D
M<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L
M;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM
M>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H
M95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I
M>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF("@A)'-T
M87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H
M:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@
M("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*
M=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G
M+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@
M/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO
M=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]
M?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@
M97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E
M<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2![
M"G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2![
M"B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G
M<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<[
M"GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D
M,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#
M86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@
M)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H
M;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]4
M14U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z
M.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@
M0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I
M;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!
M.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I
M;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE
M('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F
M:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D
M>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@
M87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*:68@*"1Z
M:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI
M('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO
M+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@
M*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O
M<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@
M)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T
M(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*8VQO
M<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z
M.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R
M(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB
M:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F
M:6YE9"`D9&%T85]P;W,I('L*<F5A9"!?1D@L("1L;V%D97(L("1D871A7W!O
M<SL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^
M.PI]"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>
M*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I
M.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["FUY("1P87)?8VQE86X@/2`B
M/3$B.PIM>2`D<&%S<U]P87)?8VQE86X@/2!U8R`B7U]P87-S7W!A<E]C;&5A
M;E]?(CL*)&QO861E<B`]?B!S>R@_/#TD>W!A<W-?<&%R7V-L96%N?2DH("LI
M?0I[)'!A<E]C;&5A;B`N("@B("(@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D
M<&%R7V-L96%N*2DI?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD*;W(@9&EE
M('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D;W5T(CH@)"%=.PII9B`H
M)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S
M*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N
M9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H
M;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]
M*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@
M)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R
M961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I
M9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@
M9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME
M>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM
M>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I
M;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY
M("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\
M:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@
M*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R
M968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R
M968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@
M)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@
M=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]
M*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI
M8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B
M+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY
M("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE
M+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D
M=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL
M92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO
M)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O
M7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M
M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^
M<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS
M<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H
M)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I
M*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D
M($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA
M;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW<FET951O1FEL94AA;F1L
M92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R
M('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*?0HD8V%C:&5?;F%M92`]
M('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*:68@
M*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=
M*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1T
M:"P@(CPZ<F%W(BP@)&]U=#L*)&-T>"T^861D9FEL92@D=&@I.PIC;&]S92`D
M=&@["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N
M86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C
M:&5?;F%M92D["B1C86-H95]N86UE("X]("1C86-H95]M87)K97(["FUY("1O
M9F9S970@/2`D9F@M/G1E;&P@*R!L96YG=&@H)&-A8VAE7VYA;64I("T@;&5N
M9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`IP86-K*"=.
M)RP@)&]F9G-E="DL"B1005)?34%'24,I"B8F("1F:"T^8VQO<V4*;W(@9&EE
M('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM
M;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@
M)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ
M1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV
M93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@
M)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(
M86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G
M;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I
M.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD
M<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*
M:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T
M(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE
M;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M
M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D
M;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF
M:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I
M/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E
M<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL
M("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]
M("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P
M:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T
M("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@
M(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R
M+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@
M;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA
M;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,
M:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6
M.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L
M92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;
M+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@
M>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY
M("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF
M:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H
M.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[
M(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L
M97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E
M(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR
M97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V
M>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/
M.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I
M<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U
M:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5
M;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE
M9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E
M<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@
M7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$[
M"G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@
M<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W
M*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64[
M"FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@
M9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I
M("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H
M9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@
M>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\
M("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]
M<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER
M+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2![
M"B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H
M+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P
M<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?
M;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&
M24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*"1C86-H95]M87)K97(I+"`P.PIM
M>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@;&5N9W1H*"1C86-H95]M87)K97(I
M.PII9B`H)&)U9B!E<2`D8V%C:&5?;6%R:V5R*2!["G-E96L@)&9H+"`D;6%G
M:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H)&-A8VAE7VUA
M<FME<BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F:"P@)&)U9BP@
M)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD8V%C:&5?9&ER
M(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF("@A)&-A8VAE
M7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6>U!!4E]#3$5!
M3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD8V%C:&5?9&ER
M(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%35!](#T@)'-T
M;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?
M87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F
M=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL
M;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;7D@)&9H
M.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@*'!R:6YT("1F
M:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E+"`D=&5M<&YA
M;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN
M86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE
M.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?
M4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2![
M"B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6
M>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0
M?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD
M97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6
M>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI
M;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@
M>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?
M97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*?0I]
M"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L
M("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@
M86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S>7-[
M7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U]
M)'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[
M7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D
M9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER
M)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE
M('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@
M*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N
M86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H
M9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F
M:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D
M8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S
M>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@
M*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@
M96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@
M4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2![
M"F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!435!$25(@5$5-
M4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@)$5.5GLB4$%2
M7T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/0D%,7R1?(GT[
M"GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!
M3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G
M9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?
M7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@
M0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@
M<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB
M97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M
M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P
M87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A
M;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL
M92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R
M;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH
M*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I
M9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)2
M3U(["C$["E]?14Y$7U\*`````'!E<FQX<VDN8P`````````!(T5G`````(FK
MS>\`````_MRZF`````!V5#(0`````/#ATL,````````````````!&P,[_```
M`!X```"PB?__1`8``/"+__\4`0``0(S__R@!``!PC/__/`$``+",__]0`0``
M`(W__W0!```0C?__B`$```2.___P`0``H([__Q@"```0D/__:`(``!"1__^@
M`@``-)/___0"``"PD___&`,``/"3__\X`P``U)3__VP#``#@E/__@`,``!"7
M___L`P``0)?__Q`$``"PF/__@`0``'2=__^\!```!)[__^`$```DGO__``4`
M`%"?__\\!0``D*;__]0%``#PJ/__"`8``""J__]X!@``X+K__YP&```@N___
MO`8``#"\___T!@``\+W__S`'````````$``````````!>E(`!'@>`1L,'P`0
M````&````-2*__\T`````$$''A`````L````$(O__S``````````$````$``
M```LB___/``````````@````5````%B+__](`````$$.()T$G@-"DP).WMW3
M#@`````0````>````(2+__\$`````````&0```",````@(O___0`````00Y`
MG0B>!T*3!I0%0I@!EP)&E@.5!%;6U4'8UT/>W=/4#@!!#D"3!I0%E026`Y<"
MF`&=")X'3];50=C70=[=T]0.`$$.0),&E`6=")X'0I<"F`%!V-<`)````/0`
M```,C/__E`````!!#K`!G1:>%423%%8*WMW3#@!!"P```$P````<`0``@(S_
M_VP!````0P[``9T8GA=&E!63%D34TTC>W0X`00[``9,6E!6=&)X70983E11V
M"M330=;500M)T]35UD&4%9,60983E10`-````&P!``"@C?__``$```!"#L`@
M1)V(!)Z'!$*3A@24A01#E80$EH,$8@K=WM76T]0.`$$+``!0````I`$``&B.
M__\D`@```$$.8)T,G@M"DPJ4"4V5")8'EP:8!7\*WMW7V-76T]0.`$$+2IH#
MF01="MK900M(V=I"F02:`T/9VD&:`YD$0MK9```@````^`$``#B0__]T````
M`$$.()T$G@-"DP)2WMW3#@`````<````'`(``)"0__\X`````$,.$)T"G@%$
MWMT.`````#`````\`@``L)#__^0`````0@[00$2=B@B>B0A"DX@(E(<(0I6&
M"&L*W=[5T]0.`$$+```0````<`(``&"1__\$`````````&@```"$`@``6)'_
M_RP"````0@[@(4.=G`2>FP1"DYH$E)D$0Y68!):7!%T*W=[5UM/4#@!!"TB8
ME027E@1$FI,$F90$=@K8UT':V4$+5@K8UT':V4$+1-?8V=I!F)4$EY8$09J3
M!)F4!````"````#P`@``')/__RP`````00X@G02>`T.3`D;>W=,.`````&P`
M```4`P``*)/__V@!````0@[`($.=B`2>AP1&E80$1)2%!).&!&;4TT'50=W>
M#@!!#L`@E80$G8@$GH<$0=5,W=X.`$$.P""3A@24A025A`2=B`2>AP1,"M33
M0M5""T'3U-5!E(4$DX8$096$!``X````A`,``"B4___$!````$$.8)T,G@M$
MDPJ4"4:5")8'EP:8!9D$`QL!"M[=V=?8U=;3U`X`00L````@````P`,``+"8
M__^0`````$$.,)T&G@5$DP10"M[=TPX`00L<````Y`,``!R9__\@`````$$.
M$)T"G@%&WMT.`````#@````$!```')G__RP!````00Y`G0B>!T23!I0%0I4$
ME@-8"M[=U=;3U`X`00M-"M[=U=;3U`X`00L``)0```!`!```#)K__S@'````
M0@ZP@P)#G;0@GK,@0I6P():O($>3LB"4L2"7KB"8K2!#F:P@FJL@6)RI()NJ
M(`)Y"MS;0=W>V=K7V-76T]0.`$$+`HO;W%'=WMG:U]C5UM/4#@!!#K"#`I.R
M()2Q()6P():O()>N()BM()FL()JK()NJ()RI()VT()ZS(`*+V]Q!G*D@FZH@
M,````-@$``"TH/__7`(```!!#E"="IX)0I,(E`=#E0:6!427!`)J"M[=U]76
MT]0.`$$+`#@````,!0``X*+__S`!````00Y`G0B>!T23!I0%0I4$E@-?"M[=
MU=;3U`X`00M3"M[=U=;3U`X`00L``#````!(!0``9(/__QP"````00Y@G0R>
M"T63"I0)E0B6!P)?"M[=U=;3U`X`00L````````@````?`4``*"C__^X$```
M`$$.H`5&G52>4P,E!`K=W@X`00L<````H`4``#RT__]``````$$.$)T"G@%.
MWMT.`````#0```#`!0``7+3__P@!````00Y`G0B>!T.3!I0%0Y4$E@-#EP*8
M`6,*WMW7V-76T]0.`$$+````.````/@%```TM?__P`$```!!#D"=")X'0Y,&
ME`5#E026`T(%2`("8`K>W=76T]0&2`X`00L`````````$````#0&``"XMO__
M#```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````"0(@```````$`B`````````0``
M``````#^`@````````$`````````#@,````````!`````````!@#````````
M#``````````@&P````````T`````````C%,````````9`````````'C[`0``
M````&P`````````(`````````!H`````````@/L!```````<``````````@`
M````````]?[_;P````"8`@````````4`````````0`T````````&````````
M`(`#````````"@````````"9!`````````L`````````&``````````5````
M`````````````````P````````"8_0$```````(`````````H`4````````4
M``````````<`````````%P````````"`%0````````<`````````$!,`````
M```(`````````'`"````````"0`````````8`````````!X`````````"```
M``````#[__]O``````$```@`````_O__;P````"P$@```````/___V\`````
M`@````````#P__]O`````-H1````````^?__;P`````.````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````0!L```````!`&P```````$`;````````0!L```````!`&P``
M`````$`;````````0!L```````!`&P```````$`;````````0!L```````!`
M&P```````$`;````````0!L```````!`&P```````$`;````````0!L`````
M``!`&P```````$`;````````0!L```````!`&P```````$`;````````0!L`
M``````!`&P```````$`;````````0!L```````!`&P```````$`;````````
M0!L```````!`&P```````$`;````````0!L```````!`&P```````$`;````
M````0!L```````!`&P```````$`;````````0!L```````!`&P```````$`;
M````````0!L```````!`&P```````$`;````````0!L```````!`&P``````
M`$`;````````0!L```````!`&P```````$`;````````0!L```````!`&P``
M`````$`;````````0!L```````!`&P```````$`;````````0!L```````!`
M&P```````$`;````````0!L```````!`&P```````$`;````````B/L!````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````!`'P``````````````````"``"``````#_____`````%!7````
M````$%0```````````````````!5````````,%<````````X5P```````$!7
M````````2%<``````````````````!A7````````(%<`````````````````
M`%A7````````1T-#.B`H1&5B:6%N(#$R+C(N,"TQ*2`Q,BXR+C```"YS:'-T
M<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G
M`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N
M=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I
M;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A
M>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE
M;G0`````````````````````````````````````````````````````````
M``````````````````````````````L````!`````@`````````X`@``````
M`#@"````````&P````````````````````$````````````````````3````
M!P````(`````````5`(```````!4`@```````"0````````````````````$
M````````````````````)@````<````"`````````'@"````````>`(`````
M```@````````````````````!````````````````````#0```#V__]O`@``
M``````"8`@```````)@"````````Z``````````%``````````@`````````
M```````````^````"P````(`````````@`,```````"``P```````,`)````
M````!@````,````(`````````!@`````````1@````,````"`````````$`-
M````````0`T```````"9!````````````````````0``````````````````
M`$X```#___]O`@````````#:$0```````-H1````````T``````````%````
M``````(``````````@````````!;````_O__;P(`````````L!(```````"P
M$@```````&``````````!@````(````(````````````````````:@````0`
M```"`````````!`3````````$!,```````!P`@````````4`````````"```
M```````8`````````'0````$````0@````````"`%0```````(`5````````
MH`4````````%````%0````@`````````&`````````!^`````0````8`````
M````(!L````````@&P```````!@````````````````````$````````````
M````````>0````$````&`````````$`;````````0!L```````#@`P``````
M````````````$````````````````````(0````!````!@````````!`'P``
M`````$`?````````3#0``````````````````$````````````````````"*
M`````0````8`````````C%,```````",4P```````!0`````````````````
M```$````````````````````D`````$````"`````````*!3````````H%,`
M``````#P00``````````````````$````````````````````)@````!````
M`@````````"0E0```````)"5````````_`````````````````````0`````
M``````````````"F`````0````(`````````D)8```````"0E@```````$@&
M```````````````````(````````````````````L`````X````#````````
M`'C[`0``````>/L````````(````````````````````"``````````(````
M`````+P````/`````P````````"`^P$``````(#[````````"```````````
M``````````@`````````"`````````#(````!@````,`````````B/L!````
M``"(^P```````!`"````````!@`````````(`````````!``````````T0``
M``$````#`````````)C]`0``````F/T```````!H`@``````````````````
M"``````````(`````````-8````!`````P````````````(``````````0``
M````@`````````````````````@```````````````````#<````"`````,`
M````````@``"``````"```$``````"@````````````````````(````````
M````````````X0````$````P````````````````````@``!```````>````
M`````````````````0`````````!``````````$````#````````````````
M`````````)X``0``````Z@````````````````````$`````````````````
"````
